==> mysql-shell_8.0.36+dfsg.orig.tar.xz: mysql-shell-8.0.36-src/unittest/mysqlshdk/libs/azure/test_utils.h <==
/* Copyright (c) 2022, Oracle and/or its affiliates.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.

 This program is also distributed with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms, as
 designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
 separately licensed software that they have included with MySQL.
 This program is distributed in the hope that it will be useful,  but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 the GNU General Public License, version 2.0, for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */

#ifndef UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_
#define UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_

#include <string>

#include "mysqlshdk/libs/azure/blob_storage_config.h"
#include "mysqlshdk/libs/azure/blob_storage_container.h"
#include "mysqlshdk/libs/azure/blob_storage_options.h"
#include "mysqlshdk/libs/utils/utils_file.h"

namespace testing {

using mysqlshdk::azure::Blob_container;
using mysqlshdk::azure::Blob_storage_config;
using mysqlshdk::azure::Blob_storage_options;
using mysqlshdk::azure::Storage_config_ptr;

std::shared_ptr<Blob_storage_config> get_config(
    const std::string &container,
    mysqlshdk::azure::Blob_storage_options::Operation operation =
        mysqlshdk::azure::Blob_storage_options::Operation::WRITE);
void create_container(const std::string &name);
void clean_container(Blob_container &container);
void delete_container(const std::string &name);
}  // namespace testing

#endif  // UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_

==> mysql-shell_8.4.4+dfsg.orig.tar.xz: mysql-shell-8.4.4-src/unittest/mysqlshdk/libs/azure/test_utils.h <==
/* Copyright (c) 2022, 2024, Oracle and/or its affiliates.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.

 This program is designed to work with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
 separately licensed software that they have either included with
 the program or referenced in the documentation.

 This program is distributed in the hope that it will be useful,  but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 the GNU General Public License, version 2.0, for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */

#ifndef UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_
#define UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_

#include <string>

#include "mysqlshdk/libs/azure/blob_storage_config.h"
#include "mysqlshdk/libs/azure/blob_storage_container.h"
#include "mysqlshdk/libs/azure/blob_storage_options.h"
#include "mysqlshdk/libs/utils/utils_file.h"

namespace testing {

using mysqlshdk::azure::Blob_container;
using mysqlshdk::azure::Blob_storage_config;
using mysqlshdk::azure::Blob_storage_options;
using mysqlshdk::azure::Storage_config_ptr;

std::shared_ptr<Blob_storage_config> get_config(
    const std::string &container,
    mysqlshdk::azure::Blob_storage_options::Operation operation =
        mysqlshdk::azure::Blob_storage_options::Operation::WRITE);
void create_container(const std::string &name);
void clean_container(Blob_container &container);
void delete_container(const std::string &name);
}  // namespace testing

#endif  // UNITTEST_MYSQLSHDK_LIBS_AZURE_UTILS_H_
